from distutils.core import setup
setup(
    name="alsolib",
    version="0.6.0",
    description="爱搜功能库0.6.0，线路一定要用python原版,©爱搜浏览器团队 版权所有",
    author="asunc",
    author_email="3182305655@qq.com",
    py_modules=["alsolib\\alsolib",'alsolib\\alsoapi']
)